@@ -1,17 +1,17 @@
-/* 
+/*
  *  OsmoGGSN - Gateway GPRS Support Node
  *  Copyright (C) 2002 Mondru AB.
- * 
+ *
  *  The contents of this file may be used under the terms of the GNU
  *  General Public License Version 2, provided that the above copyright
  *  notice and this permission notice is included in all copies or
  *  substantial portions of the software.
- * 
+ *
  */
 
 /*
- * gtpie.c: Contains functions to encapsulate and decapsulate GTP 
- * information elements 
+ * gtpie.c: Contains functions to encapsulate and decapsulate GTP
+ * information elements
  *
  *
  * Encapsulation
@@ -37,7 +37,7 @@
 #include <netinet/in.h>
 #include <string.h>
 
-#include "gtpie.h"
+#include <osmocom/gtp/gtpie.h>
 
 /*! Encode a TLV type Information Element.
  *  \param[inout] p Pointer to output packet to which IE is appended
